@@ -42,11 +42,12 @@ TWEAK_SORT_LAST = 1e3
 LOG = logging.getLogger(__name__)
 
 class Tweak:
+    main_window = None
     def __init__(self, name, description, **options):
         self.name = name
         self.description = description
         self.group_name = options.get("group_name",_("Miscellaneous"))
-        self.loaded = True
+        self.loaded = options.get("loaded", True)
         self.widget_sort_hint = None
 
         self._search_cache = None
@@ -121,11 +122,11 @@ class TweakModel(Gtk.ListStore):
 
     @property
     def tweaks(self):
-        return [t for row in self for t in row[TweakModel.COLUMN_TWEAK].tweaks]
+        return (t for row in self for t in row[TweakModel.COLUMN_TWEAK].tweaks)
 
     @property
     def tweak_groups(self):
-        return [row[TweakModel.COLUMN_TWEAK] for row in self]
+        return (row[TweakModel.COLUMN_TWEAK] for row in self)
 
     def load_tweaks(self):
         if 1:
@@ -177,7 +178,7 @@ class TweakModel(Gtk.ListStore):
         group.set_tweaks(tweak)
       
     def search_matches(self, txt):
-        return [t for t in self.tweaks if t.search_matches(txt)]
+        return (t for t in self.tweaks if t.search_matches(txt))
 
     def get_tweakgroup_iter(self, name):
         return self._tweak_group_iters[name]
